`xoutil.eight.mixins`:mod: - functions to create helper classes and mixins
==========================================================================

.. automodule:: xoutil.eight.mixins
   :members:
